@@ -140,7 +140,8 @@ mfxStatus CheckFrameInfoCommon(mfxFrameInfo  *info, mfxU32 codecId)
         if (   info->FourCC != MFX_FOURCC_P010 && info->FourCC != MFX_FOURCC_P210
             && info->FourCC != MFX_FOURCC_Y210
             && info->FourCC != MFX_FOURCC_P016 && info->FourCC != MFX_FOURCC_Y216
-            && info->FourCC != MFX_FOURCC_Y416 && info->FourCC != MFX_FOURCC_R16)
+            && info->FourCC != MFX_FOURCC_Y416 && info->FourCC != MFX_FOURCC_R16
+            )
             MFX_RETURN(MFX_ERR_INVALID_VIDEO_PARAM);
     }
     if (codecId != MFX_CODEC_JPEG)
@@ -338,12 +339,16 @@ mfxStatus CheckFrameInfoCodecs(mfxFrameInfo  *info, mfxU32 codecId)
                   || info->ChromaFormat == MFX_CHROMAFORMAT_YUV444
                   , MFX_ERR_INVALID_VIDEO_PARAM);
         break;
+    case MFX_CODEC_AV1:
+        MFX_CHECK(info->ChromaFormat == MFX_CHROMAFORMAT_YUV420
+            , MFX_ERR_INVALID_VIDEO_PARAM);
+        break;
     default:
         MFX_CHECK(info->ChromaFormat == MFX_CHROMAFORMAT_YUV420 || info->ChromaFormat == MFX_CHROMAFORMAT_YUV400, MFX_ERR_INVALID_VIDEO_PARAM);
         break;
     }
 
-    switch (codecId) 
+    switch (codecId)
     {
 #if defined(MFX_ENABLE_VVC_VIDEO_DECODE)
     case MFX_CODEC_VVC:
@@ -365,7 +370,7 @@ mfxStatus CheckFrameInfoCodecs(mfxFrameInfo  *info, mfxU32 codecId)
             || info->FourCC == MFX_FOURCC_Y210
             || info->FourCC == MFX_FOURCC_P016
             || info->FourCC == MFX_FOURCC_Y216
-            || info->FourCC == MFX_FOURCC_Y416) 
+            || info->FourCC == MFX_FOURCC_Y416)
         {
             MFX_CHECK(info->Shift == 1, MFX_ERR_INVALID_VIDEO_PARAM);
         }
@@ -471,7 +476,8 @@ static mfxStatus CheckVideoParamCommon(mfxVideoParam *in, eMFXHWType type)
         || in->mfx.FrameInfo.FourCC == MFX_FOURCC_Y210
         || in->mfx.FrameInfo.FourCC == MFX_FOURCC_P016
         || in->mfx.FrameInfo.FourCC == MFX_FOURCC_Y216
-        || in->mfx.FrameInfo.FourCC == MFX_FOURCC_Y416)
+        || in->mfx.FrameInfo.FourCC == MFX_FOURCC_Y416
+        )
     {
         if (type == MFX_HW_UNKNOWN)
         {
@@ -1016,7 +1022,6 @@ void mfxVideoParamWrapper::CopyVideoParam(const mfxVideoParam & par)
     ExtParam = NumExtParam ? m_buffers.GetBuffers() : 0;
 }
 
-inline
 mfxU32 GetMinPitch(mfxU32 fourcc, mfxU16 width)
 {
     switch (fourcc)
@@ -1045,7 +1050,7 @@ mfxU32 GetMinPitch(mfxU32 fourcc, mfxU16 width)
         case MFX_FOURCC_A2RGB10:     return width * 4;
 
         case MFX_FOURCC_ARGB16:
-        case MFX_FOURCC_ABGR16:  
+        case MFX_FOURCC_ABGR16:
         case MFX_FOURCC_ABGR16F:     return width * 8;
 
         case MFX_FOURCC_YUY2:
