@@ -168,6 +168,19 @@ namespace UMC_AV1_DECODER
         return false;
     }
 
+
+    void AV1Decoder::AV1IncrementReference(const std::string& function, int line, AV1DecoderFrame* frame)
+    {
+        frame->IncrementReference();
+        DPBLOG_PRINT(function, line, "[+]", frame, frame->GetRefCounter());
+    }
+
+    void AV1Decoder::AV1DecrementReference(const std::string& function, int line, AV1DecoderFrame* frame)
+    {
+        frame->DecrementReference();
+        DPBLOG_PRINT(function, line, "[-]", frame, frame->GetRefCounter());
+    }
+
     UMC::Status AV1Decoder::DecodeHeader(UMC::MediaData* in, UMC_AV1_DECODER::AV1DecoderParams& par)
     {
         if (!in)
@@ -285,10 +298,12 @@ namespace UMC_AV1_DECODER
             if ((fh.refresh_frame_flags >> i) & 1)
             {
                 if (!prevFrameDPB.empty() && prevFrameDPB[i] && prevFrameDPB[i]->UID != -1)
-                    prevFrameDPB[i]->DecrementReference();
+                {
+                    AV1DecrementReference(__FUNCTION__, __LINE__, prevFrameDPB[i]);
+                }
 
                 updatedFrameDPB[i] = const_cast<AV1DecoderFrame*>(prevFrame);
-                prevFrame->IncrementReference();
+                AV1IncrementReference(__FUNCTION__, __LINE__, prevFrame); 
             }
         }
 
@@ -401,7 +416,7 @@ namespace UMC_AV1_DECODER
             repeateFrame = pFrame->GetMemID();
 
             //repeat frame reference counter increase here, and will decrease in queryframe()
-            pFrame->IncrementReference();
+            AV1IncrementReference(__FUNCTION__, __LINE__, pFrame);
 
             FrameHeader const& Repeat_H = pFrame->GetFrameHeader();
             if (!Repeat_H.showable_frame)
@@ -415,10 +430,12 @@ namespace UMC_AV1_DECODER
                     if ((Repeat_H.refresh_frame_flags >> i) & 1)
                     {
                         if (!frameDPB.empty() && frameDPB[i] && frameDPB[i]->GetRefCounter())
-                           frameDPB[i]->DecrementReference();
-
+                        {
+                            AV1DecrementReference(__FUNCTION__, __LINE__, frameDPB[i]);
+                        } 
                         frameDPB[i] = const_cast<AV1DecoderFrame*>(pFrame);
-                        pFrame->IncrementReference();
+                        AV1IncrementReference(__FUNCTION__, __LINE__, pFrame);
+                       
                     }
                 }
             }
@@ -591,8 +608,9 @@ namespace UMC_AV1_DECODER
         frame->SetFrameTime(frame_order * in_framerate);
         frame->SetFrameOrder(frame_order);
         FrameHeader strFrameHeader = frame->GetFrameHeader();
-        if (strFrameHeader.show_frame || strFrameHeader.show_existing_frame)//add for fix -DecoderdOrder hang issue
+        if (strFrameHeader.show_frame || frame->ShowAsExisting()) //display frame or repeat frame, frame order ++
             frame_order++;
+
     }
 
     UMC::Status AV1Decoder::GetFrame(UMC::MediaData* in, UMC::MediaData*)
@@ -681,7 +699,6 @@ namespace UMC_AV1_DECODER
                 uint32_t lst_shift;
                 bs.ReadOBUInfo(obuInfo);
                 const AV1_OBU_TYPE obuType = obuInfo.header.obu_type;
-                auto frame_source = dynamic_cast<SurfaceSource*>(allocator);
 
                 if (obuInfo.header.obu_type > OBU_PADDING)
                     return UMC::UMC_ERR_INVALID_PARAMS;
@@ -725,11 +742,8 @@ namespace UMC_AV1_DECODER
                         Update_drc(sequence_header.get());
                         m_RecreateSurfaceFlag = IsNeedRecreateSurface(old_seqHdr.get(), sequence_header.get());
 
-                        if ((frame_source && !frame_source->GetSurfaceType()) || (frame_source->GetSurfaceType() && m_RecreateSurfaceFlag))
-                        {
-                            // new resolution required
-                            return UMC::UMC_NTF_NEW_RESOLUTION;
-                        }
+                        // new resolution required
+                        return UMC::UMC_NTF_NEW_RESOLUTION;
                     }
 
                     set_seq_header_ready();
@@ -768,11 +782,9 @@ namespace UMC_AV1_DECODER
                         PreFrame_id = OldPreFrame_id;
 
                         m_RecreateSurfaceFlag = IsNeedRecreateSurface(old_seqHdr.get(), sequence_header.get());
-                        if ((frame_source && !frame_source->GetSurfaceType()) || (frame_source->GetSurfaceType() && m_RecreateSurfaceFlag))
-                        {
-                            // new resolution required
-                            return UMC::UMC_NTF_NEW_RESOLUTION;
-                        }
+
+                        // new resolution required
+                        return UMC::UMC_NTF_NEW_RESOLUTION;
                     }
 
                     fh.output_frame_width_in_tiles  = tlInfo.frameWidthInTiles;
@@ -921,6 +933,10 @@ namespace UMC_AV1_DECODER
                 }
  
                 CompleteDecodedFrames(fh, pCurrFrame, pPrevFrame);
+                if (repeatedFrame)
+                {
+                    pCurrFrame->ShowAsExisting(true);
+                }
                 CalcFrameTime(pCurrFrame);
 
                 if (!pCurrFrame)
@@ -1175,31 +1191,22 @@ namespace UMC_AV1_DECODER
         if ((lastest_submitted_frame) && (!last_frame_header.show_existing_frame)) 
         {
             FrameHeader const& FH_OutTemp = lastest_submitted_frame->GetFrameHeader();
-            if (FH_OutTemp.show_frame) //display frame
+            if (FH_OutTemp.show_frame)//display frame
             {
-                bool bAdded = false;
-                for(std::vector<AV1DecoderFrame*>::iterator iter=outputed_frames.begin(); iter!=outputed_frames.end(); iter++)
+                if (!lastest_submitted_frame->mark_Added)
                 {
-                    AV1DecoderFrame* temp = *iter;
-                    if (lastest_submitted_frame->UID == temp->UID)
-                    {
-                        bAdded = true;
-                        break;
-                    }
-                }
-                if (!bAdded)
                     outputed_frames.push_back(lastest_submitted_frame);
+                    lastest_submitted_frame->mark_Added = true;
+                }
             }
             else
             {
                 // For no display frame, it decrementReference here and frame.completedecoding() in working thread
-                if(pCurrFrame)
-                {
-                    if (lastest_submitted_frame->UID == -1)
-                        lastest_submitted_frame = nullptr;
-                    else if(lastest_submitted_frame != pCurrFrame)
-                        lastest_submitted_frame->DecrementReference();
-                }
+                // If there is not enough frame(pCurrFrame = nullptr) in decode output array(DPB), it also need to decrease refcounter for last submitted non-display frame
+                if (lastest_submitted_frame->UID == -1)
+                    lastest_submitted_frame = nullptr;
+                else if(lastest_submitted_frame != pCurrFrame)
+                    AV1DecrementReference(__FUNCTION__, __LINE__, lastest_submitted_frame);
             }
         }
 
@@ -1208,17 +1215,15 @@ namespace UMC_AV1_DECODER
             AV1DecoderFrame* temp = *iter;
             if(temp->Outputted() && temp->Displayed() && temp->RefUpdated())
             {
-                temp->DecrementReference();
+                AV1DecrementReference(__FUNCTION__, __LINE__, temp);
                 iter = outputed_frames.erase(iter);
             }
             else
                 iter++;
         }
 
-        // When no available buffer, don't update Curr buffer to avoid update DPB duplicated.
-        if(pCurrFrame!= NULL)
-            lastest_submitted_frame = pCurrFrame;
-
+        //update lateset_submitted_frame even pCurrFrame is nullptr(not enough frame) 
+        lastest_submitted_frame = pCurrFrame;
         last_frame_header = fh; //store latest frame header
     }
 
@@ -1227,7 +1232,7 @@ namespace UMC_AV1_DECODER
         std::unique_lock<std::mutex> l(guard);
         if (frame->Outputted() && frame->Displayed()) //repeat frame only need these 2 flags, as repeat frame will not call ReferenceListUpdate() function
         {
-            frame->DecrementReference(); //repeat frame decrement here
+            AV1DecrementReference(__FUNCTION__, __LINE__, frame);
         }
     }
 
@@ -1260,7 +1265,7 @@ namespace UMC_AV1_DECODER
         frame->Reset(&fh);
 
         // increase ref counter when we get empty frame from DPB
-        frame->IncrementReference();
+        AV1IncrementReference(__FUNCTION__, __LINE__, frame);
 
         return frame;
     }
@@ -1274,7 +1279,7 @@ namespace UMC_AV1_DECODER
 
         frame->UID = counter++;
         frame->Reset(&fh);
-        frame->IncrementReference();
+        AV1IncrementReference(__FUNCTION__, __LINE__, frame);
         return frame;
     }
 
